==> yappari_0.0.33.tar.gz: yappari-0.0.33/src/yappari-application/Whatsapp/ioexception.cpp <==
/* Copyright 2013 Naikel Aparicio. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY <COPYRIGHT HOLDER> ''AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL EELI REILIN OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of Eeli Reilin.
 */

#include "ioexception.h"

IOException::IOException(QAbstractSocket::SocketError e)
    : Exception()
{
    switch (e)
    {
        case QAbstractSocket::ConnectionRefusedError:
            error = "Connection refused.";
            break;

        case QAbstractSocket::RemoteHostClosedError:
            error = "Connection closed by server.";
            break;

        case QAbstractSocket::HostNotFoundError:
            error = "Can't resolve server address (DNS problem?).";
            break;

        case QAbstractSocket::SocketTimeoutError:
            // error = "Connection timed out.";
            error = "Connection error.";
            break;

        case QAbstractSocket::NetworkError:
            error = "Network error.";
            break;

        case QAbstractSocket::UnknownSocketError:
            error = "Unknown socket error.";
            break;

        default:
            error = "There has been an unknown error: " + QString::number(e);
            break;
    }
}

==> yappari_0.0.35.tar.gz: yappari-0.0.35/src/yappari-application/Whatsapp/ioexception.cpp <==
/* Copyright 2013 Naikel Aparicio. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY <COPYRIGHT HOLDER> ''AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL EELI REILIN OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * official policies, either expressed or implied, of Eeli Reilin.
 */

#include "ioexception.h"

IOException::IOException(QAbstractSocket::SocketError e)
    : Exception()
{
    switch (e)
    {
        case QAbstractSocket::ConnectionRefusedError:
            error = "Connection refused.";
            break;

        case QAbstractSocket::RemoteHostClosedError:
            error = "Connection closed by server.";
            break;

        case QAbstractSocket::HostNotFoundError:
            error = "Can't resolve server address (DNS problem?).";
            break;

        case QAbstractSocket::SocketTimeoutError:
            error = "Connection timed out.";
            // error = "Connection error.";
            break;

        case QAbstractSocket::NetworkError:
            error = "Network error.";
            break;

        case QAbstractSocket::UnknownSocketError:
            error = "Unknown socket error.";
            break;

        default:
            error = "There has been an unknown error: " + QString::number(e);
            break;
    }
}
